@@ -98,3 +98,12 @@ register_codec(Adler32)
 
 from numcodecs.json import JSON
 register_codec(JSON)
+
+try:
+    from numcodecs import vlen
+    from numcodecs.vlen import VLenUTF8, VLenBytes, VLenArray
+    register_codec(VLenUTF8)
+    register_codec(VLenBytes)
+    register_codec(VLenArray)
+except ImportError:  # pragma: no cover
+    pass
